// scss-lint:disable PlaceholderInExtend
.paginator {
  @extend .clearfix;
  overflow: auto;
  padding-top: .5rem;
  white-space: nowrap;

  span,
  a:not(.showall) {
    background: $pag-bg;
    border: 1px solid $pag-border-color;
    color: $pag-color;
    display: inline-block;
    height: 40px;
    line-height: 40px;
    padding: 0 !important;
    text-align: center;
    width: 40px;

    &:hover {
      background: $pag-hover-bg;
    }
  }

  .end {
    @extend .mr-3;
  }

  .this-page {
    background: $pag-selected-bg;
    color: $pag-selected-color;

    &:hover {
      background: $pag-selected-bg;
    }
  }

  .showall {
    @extend .btn;
    @extend .btn-outline-primary;
    margin-top: -5px;
  }

  input {
    @extend .btn;
    @extend .btn-success;
    margin-top: -4px;

    @include media-breakpoint-up(md) {
      float: right;
      margin-top: 0;
    }
  }
}
