// scss-lint:disable IdSelector NestingDepth PlaceholderInExtend
body:not(.login):not(.page-logout) #header {
  &.expand {
    @extend .d-flex;
    @extend .d-lg-none;
    @extend .navbar-expand-lg;
  }
}

body.page-logout #header {
  .navbar-toggler {
    display: none;
  }
}

#header {
  @extend .navbar;
  @extend .navbar-dark;
  @extend .bg-dark;

  align-items: center;
  background: $navbar-bg !important;
  color: $navbar-color;
  flex-direction: row !important;

  strong {
    color: $navbar-color;
    padding-left: 0;

    &::before {
      content: '\f007';
      display: inline-block;
      font-family: 'Font Awesome\ 5 Free';
      margin-right: 5px;
    }
  }

  a {
    color: $navbar-link-color;

    &:hover {
      color: $navbar-link-color-hover;
      text-decoration: none;
    }

    &.dropdown-item {
      color: $navbar-dropdown-link-color;
    }
  }

  #user-tools {
    @extend .d-inline-flex;

    > a {
      @extend .navbar-text;
      order: 2;
    }

    .dropdown-menu {
      @include media-breakpoint-up(md) {
        left: auto;
        right: 0;
      }
    }
  }

  .navbar-toggler {
    border-width: 0 !important;
    margin-right: 5px;
  }

  .nav-menu.is-active {
    background: $navbar-mobile-pane-bg;
  }
}

#branding {
  // @extend .nav-left;
  @extend .navbar-brand;
  @extend .mr-auto;
  display: inline-block;
  padding-bottom: 0;

  h1 {
    font-size: 1.4rem;
  }
}

#site-name {
  // @extend .nav-item;
}

#user-tools {
  // @extend .nav-right;
  // @extend .nav-menu;

  a {
    // @extend .nav-item;
  }

  strong {
    // @extend .button;
    // @extend .is-primary;
  }
}
