html {
  background: $navbar-bg;
  height: 100%;
}

body {
  font-weight: 300;
  min-height: 100%;
  opacity: 0;
  transition: opacity .2s linear;

  &.baton-ready {
    opacity: 1;
  }
}

button,
input,
optgroup,
select,
textarea {
  font-family: $font-family-sans-serif;
}

.clear {
  clear: both;
}

// remove django 3.1 sidebar
#toggle-nav-sidebar,
#nav-sidebar {
  display: none !important;
}
